@@ -18,6 +18,8 @@
 
 #include <kselectaction.h>
 
+class KFontActionPrivate;
+
 /**
  * @class KFontAction kfontaction.h KFontAction
  *
@@ -43,8 +45,11 @@ public:
     QWidget *createWidget(QWidget *parent) override;
 
 private:
-    class KFontActionPrivate;
-    KFontActionPrivate *const d;
+    Q_DECLARE_PRIVATE(KFontAction)
+#if KWIDGETSADDONS_BUILD_DEPRECATED_SINCE(5, 79)
+    // Unused, kept for ABI compatibility
+    const void * __kwidgetsaddons_d_do_not_use;
+#endif
 };
 
 #endif
