@@ -12,17 +12,17 @@
 #include <QComboBox>
 #include <QLabel>
 #include <QLayout>
-#include <QDesktopWidget>
 #include <QPushButton>
 #include <QStyleOption>
 #include <QTimer>
+#include <QScreen>
 
 #include <ktitlewidget.h>
 
 #include "ui_kpassworddialog.h"
 
 /** @internal */
-class Q_DECL_HIDDEN KPasswordDialog::KPasswordDialogPrivate
+class KPasswordDialogPrivate
 {
 public:
     KPasswordDialogPrivate(KPasswordDialog *q)
@@ -40,7 +40,7 @@ public:
     QMap<QString, QString> knownLogins;
     QComboBox *userEditCombo = nullptr;
     QIcon icon;
-    KPasswordDialogFlags m_flags;
+    KPasswordDialog::KPasswordDialogFlags m_flags;
     unsigned int commentRow = 0;
 };
 
@@ -54,12 +54,9 @@ KPasswordDialog::KPasswordDialog(QWidget *parent,
     d->init();
 }
 
-KPasswordDialog::~KPasswordDialog()
-{
-    delete d;
-}
+KPasswordDialog::~KPasswordDialog() = default;
 
-void KPasswordDialog::KPasswordDialogPrivate::updateFields()
+void KPasswordDialogPrivate::updateFields()
 {
     if (m_flags & KPasswordDialog::UsernameReadOnly) {
         ui.userEdit->setReadOnly(true);
@@ -69,7 +66,7 @@ void KPasswordDialog::KPasswordDialogPrivate::updateFields()
     ui.credentialsGroup->setEnabled(!q->anonymousMode());
 }
 
-void KPasswordDialog::KPasswordDialogPrivate::init()
+void KPasswordDialogPrivate::init()
 {
     ui.setupUi(q);
     ui.buttonBox->setStandardButtons(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
@@ -82,7 +79,7 @@ void KPasswordDialog::KPasswordDialogPrivate::init()
     const QString description = QApplication::translate("KPasswordDialog", "Show Contextual Help");
     ui.userEditContextHelpButton->setAccessibleName(description);
     ui.userEditContextHelpButton->setToolTip(description);
-    connect(ui.userEditContextHelpButton, &QPushButton::released, q, [this] {
+    QObject::connect(ui.userEditContextHelpButton, &QPushButton::released, q, [this] {
         QEvent ev(QEvent::WhatsThis);
         qApp->sendEvent(ui.userEdit, &ev);
     });
@@ -120,7 +117,7 @@ void KPasswordDialog::KPasswordDialogPrivate::init()
 
     updateFields();
 
-    QRect desktop = QApplication::desktop()->screenGeometry(q->topLevelWidget());
+    QRect desktop = q->topLevelWidget()->screen()->geometry();
     q->setMinimumWidth(qMin(1000, qMax(q->sizeHint().width(), desktop.width() / 4)));
     q->setIcon(QIcon::fromTheme(QStringLiteral("dialog-password")));
 }
@@ -373,7 +370,7 @@ void KPasswordDialog::setKnownLogins(const QMap<QString, QString> &knownLogins)
             this, SLOT(activated(QString)));
 }
 
-void KPasswordDialog::KPasswordDialogPrivate::activated(const QString &userName)
+void KPasswordDialogPrivate::activated(const QString &userName)
 {
     QMap<QString, QString>::ConstIterator it = knownLogins.constFind(userName);
     if (it != knownLogins.constEnd()) {
@@ -398,17 +395,17 @@ void KPasswordDialog::accept()
     QTimer::singleShot(0, this, [this] { d->actuallyAccept(); });
 }
 
-void KPasswordDialog::KPasswordDialogPrivate::actuallyAccept()
+void KPasswordDialogPrivate::actuallyAccept()
 {
     if (!q->checkPassword()) {
         return;
     }
 
     bool keep = ui.keepCheckBox->isVisibleTo(q) && ui.keepCheckBox->isChecked();
-    emit q->gotPassword(q->password(), keep);
+    Q_EMIT q->gotPassword(q->password(), keep);
 
     if (ui.userEdit->isVisibleTo(q)) {
-        emit q->gotUsernameAndPassword(q->username(), q->password(), keep);
+        Q_EMIT q->gotUsernameAndPassword(q->username(), q->password(), keep);
     }
 
     q->QDialog::accept();
