@@ -59,7 +59,7 @@
 # include <qdatetime.h>
 #endif
 
-class Q_DECL_HIDDEN KRuler::KRulerPrivate
+class KRulerPrivate
 {
 public:
     int  endOffset_length;  /* marks the offset at the end of the ruler
@@ -161,10 +161,7 @@ void KRuler::initWidget(Qt::Orientation orientation)
     d->dir = orientation;
 }
 
-KRuler::~KRuler()
-{
-    delete d;
-}
+KRuler::~KRuler() = default;
 
 #if KWIDGETSADDONS_BUILD_DEPRECATED_SINCE(5, 0)
 void
